@@ -6,8 +6,9 @@ use strict;
 use warnings;
 
 use Carp;
+use Scalar::Util qw(blessed);
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
   
 my %hash = (
     integer => qr{^[-+]?\d+$},
@@ -23,7 +24,11 @@ sub TIESCALAR{
     my $self = {};
     bless $self, $class;
 
-    $self->_type($type);
+    $self->_type(
+        blessed $type && $type->isa('Type::Tiny') ?
+            $type->compiled_check :
+            $type
+    );
 	
     return $self;
 }
@@ -39,7 +44,7 @@ sub STORE {
     my $check = $self->_check();
 
     my $success;
-    my $is_code = grep{ $_ eq ref $check }qw(CODE Type::Tiny);
+    my $is_code = 'CODE' eq ref $check;
 
     if ( !defined $check ) {
         $self->{VALUE} = $value;
@@ -121,7 +126,7 @@ Tie::CheckVariables - check/validate variables for their datatype
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
